/// <reference types="node" resolution-mode="require"/>
import { EventEmitter } from 'eventemitter3';
import { type Metadata } from '../tdf.js';
import { type Manifest, type UpsertResponse } from '../models/index.js';
export declare function streamToBuffer(stream: ReadableStream<Uint8Array>): Promise<Uint8Array>;
export type DecoratedReadableStreamSinkOptions = {
    encoding?: BufferEncoding;
    signal?: AbortSignal;
};
export declare class DecoratedReadableStream {
    KEK: null | string;
    algorithm: string;
    policyUuid?: string;
    tdfSize: number;
    fileSize: number | undefined;
    stream: ReadableStream<Uint8Array>;
    ee: EventEmitter;
    on: EventEmitter['on'];
    emit: EventEmitter['emit'];
    metadata?: Metadata;
    manifest: Manifest;
    upsertResponse?: UpsertResponse;
    fileStreamServiceWorker?: string;
    constructor(underlyingSource: UnderlyingSource & {
        fileStreamServiceWorker?: string;
    });
    getMetadata(): Promise<unknown>;
    /**
     * Dump the stream content to a buffer. This will consume the stream.
     * @return the plaintext in Buffer form.
     */
    toBuffer(): Promise<Uint8Array>;
    /**
     * Dump the stream content to a string. This will consume the stream.
     * NOTE: This interprets the stream as utf-8 encoded text, and therefore
     * will mangle any binary streams, e.g. as produced by the `zip` encoding
     * format. It is intended for use with the `HTML` encoding format, or with
     * encrypted utf-8 text documents, such as HTML or XML documents. For other formats,
     * it will produce text with encoding errors in most circumstances.
     * @return the plaintext in string form, for decrypt, or the html as a string,
     * for encrypt.
     */
    toString(): Promise<string>;
    /**
     * Dump the stream content to a local file. This will consume the stream.
     *
     * @param filepath The path of the local file to write plaintext to.
     * @param encoding The charset encoding to use. Defaults to utf-8.
     */
    toFile(filepath?: string, options?: BufferEncoding | DecoratedReadableStreamSinkOptions): Promise<void>;
}
export declare function isDecoratedReadableStream(s: unknown): s is DecoratedReadableStream;
//# sourceMappingURL=DecoratedReadableStream.d.ts.map