import { Policy } from './policy.js';
export type KeyAccessType = 'remote' | 'wrapped';
export declare function isRemote(keyAccessJSON: KeyAccess | KeyAccessObject): boolean;
export declare class Wrapped {
    readonly url: string;
    readonly kid: string | undefined;
    readonly publicKey: string;
    readonly metadata: unknown;
    readonly sid: string;
    readonly type = "wrapped";
    keyAccessObject?: KeyAccessObject;
    constructor(url: string, kid: string | undefined, publicKey: string, metadata: unknown, sid: string);
    write(policy: Policy, keyBuffer: Uint8Array, encryptedMetadataStr: string): Promise<KeyAccessObject>;
}
export declare class Remote {
    readonly url: string;
    readonly kid: string | undefined;
    readonly publicKey: string;
    readonly metadata: unknown;
    readonly sid: string;
    readonly type = "remote";
    keyAccessObject?: KeyAccessObject;
    wrappedKey?: string;
    policyBinding?: string;
    constructor(url: string, kid: string | undefined, publicKey: string, metadata: unknown, sid: string);
    write(policy: Policy, keyBuffer: Uint8Array, encryptedMetadataStr: string): Promise<KeyAccessObject>;
}
export type KeyAccess = Remote | Wrapped;
export type KeyAccessObject = {
    sid?: string;
    type: KeyAccessType;
    url: string;
    kid?: string;
    protocol: 'kas';
    wrappedKey?: string;
    policyBinding?: {
        alg: string;
        hash: string;
    };
    encryptedMetadata?: string;
};
//# sourceMappingURL=key-access.d.ts.map