/// <reference types="node" resolution-mode="require"/>
import { type DecoratedReadableStream } from '../client/DecoratedReadableStream.js';
/**
 * Read data from a seekable stream.
 * @param byteStart First byte to read. If negative, reads from the end. If absent, reads everything
 * @param byteEnd Index after last byte to read (exclusive)
 */
export type Chunker = (byteStart?: number, byteEnd?: number) => Promise<Uint8Array>;
export declare const fromBrowserFile: (fileRef: Blob) => Chunker;
export declare const fromBuffer: (source: Uint8Array | Buffer) => Chunker;
export declare const fromUrl: (location: string) => Promise<Chunker>;
export type DataSource = {
    type: 'buffer';
    location: Uint8Array;
} | {
    type: 'chunker';
    location: Chunker;
} | {
    type: 'file-browser';
    location: Blob;
} | {
    type: 'remote';
    location: string;
} | {
    type: 'stream';
    location: DecoratedReadableStream;
};
export declare const fromDataSource: ({ type, location }: DataSource) => Promise<Chunker>;
//# sourceMappingURL=chunkers.d.ts.map